pub async fn run_socket(path: &Path, overrides: ConfigOverrides) -> Result<()>Expand description
Run the authoritative server on the local Unix socket.
pub async fn run_socket(path: &Path, overrides: ConfigOverrides) -> Result<()>Run the authoritative server on the local Unix socket.