render

Function render 

pub fn render(
    workspace: &Path,
    overrides: &ConfigOverrides,
    all: bool,
) -> Result<String>
Render the overview for a session started in workspace. With all, settings left at their defaults are listed too.