Crate scv_server

Crate scv_server 

SCV’s authoritative stdio server.

Modules

components
Server-owned lifecycle for every long-running integration.

Structs

ConfigOverrides

Enums

ApprovalPolicy

Functions

default_socket_path
Return the local Unix socket used by the SCV daemon and TUI.
init_user_config
run_socket
Run the authoritative server on the local Unix socket.
run_stdio
service_name
Return the user service name for the selected SCV instance.
service_unit_path
update_index_url
user_home_path