SCV’s authoritative stdio server.
Modules
- components
- Server-owned lifecycle for every long-running integration.
Structs
Enums
Functions
- default_
socket_ path - Return the local Unix socket used by the SCV daemon and TUI.
- init_
user_ config - run_
socket - Run the authoritative server on the local Unix socket.
- run_
stdio - service_
name - Return the user service name for the selected SCV instance.
- service_
unit_ path - update_
index_ url - user_
home_ path