Crate scv_server

Crate scv_server 

SCV’s authoritative stdio server.

Structs

ConfigOverrides

Enums

ApprovalPolicy

Functions

default_socket_path
Return the local Unix socket used by the SCV daemon and TUI.
init_user_config
run_socket
Run the authoritative server on the local Unix socket.
run_stdio
update_index_url