SCV’s authoritative stdio server.
Structs
Enums
Functions
- default_
socket_ path - Return the local Unix socket used by the SCV daemon and TUI.
- init_
user_ config - run_
socket - Run the authoritative server on the local Unix socket.
- run_
stdio